@@ -1,15 +1,37 @@
 #!/usr/bin/python3
+# -*- coding: utf-8 -*-
 
-licence={}
-licence['en']="""\
+from PyQt6.QtCore import pyqtSignal, QEvent, QTranslator, QLocale, QRectF, QDir
+from PyQt6.QtGui import QColor
+from PyQt6.QtWidgets import QMainWindow, QWidget, QMessageBox, QApplication, QFileDialog
+
+from .reactifs import setupUi as reactifs_setupUi
+from .acidebase import abHTMLparser
+from .version import versionString, version
+from .phplot import phPlot
+from .curvecontrol import CurveControl
+
+import pyqtgraph as pg
+import numpy as np
+import PIL.Image
+
+import sys
+import re
+import os
+import pickle
+import jsonpickle
+
+licence = {}
+licence['en'] = """\
 This file is part of the project PYACIDOBASIC
 
 pyacidobasic version %s:
 
 a program to simulate acido-basic equilibria
 
-Copyright (C) 2010-2018 Georges Khaznadar <georgesk@debian.org>
-          (C) 2013 Jd Bourlier <jd.bourlier@gmail.com>
+    Copyright (C) 2010-2013 Georges Khaznadar <georgesk@debian.org>
+    Copyright (C) 2013 Jd Bourlier <jd.bourlier@gmail.com>
+    Copyright (C) 2024 philippe DALET <philippe.dalet@gmail.com>
 
 This program is free software: you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -26,112 +48,102 @@ along with this program.  If not, see
 <http://www.gnu.org/licenses/>.
 """
 
-licence['fr']=u"""
+licence['fr'] = """
     pyacidobasic version %s:
 
     un programme pour simuler des équilibres acido-basiques
-    
-    Copyright (C) 2010-2018 Georges Khaznadar <georgesk@ofset=debian.org>
-    
-    Ce projet est un logiciel libre : vous pouvez le redistribuer, le modifier selon les terme de la GPL (GNU Public License) dans les termes de la Free Software Foundation concernant la version 3 ou plus de la dite licence.
-    
-    Ce programme est fait avec l'espoir qu'il sera utile mais SANS AUCUNE GARANTIE. Lisez la licence pour plus de détails.
-    
+
+    Copyright (C) 2010-2024 Georges Khaznadar <georgesk@ofset=debian.org>
+
+    Ce projet est un logiciel libre : vous pouvez le redistribuer, le modifier selon les
+    termes de la GPL (GNU Public License) dans les termes de la Free Software Foundation
+    concernant la version 3 ou plus de la dite licence.
+
+    Ce programme est fait avec l'espoir qu'il sera utile mais SANS AUCUNE GARANTIE.
+    Lisez la licence pour plus de détails.
+
     <http://www.gnu.org/licenses/>.
 """
 
-from PyQt5.QtCore import *
-from PyQt5.QtGui import *
-from PyQt5.QtWidgets import *
-
-from .reactifs import setupUi as reactifs_setupUi
-from .acidebase import abHTMLparser
-from .version import versionString, version
-from .phplot import phPlot
-from .doubleplotwidget import DoublePlotWidget
-from .curveControl import CurveControl
-
-import pyqtgraph as pg
-import numpy as np
-import PIL.Image
-
-import os.path, pickle, jsonpickle, re, sys
-
 class acidoBasicMainWindow(QMainWindow):
-    indicators=['rien.svg.png', 'bbt.svg.png', 'phenolphtaleine.svg.png',
-                'helianthine.svg.png', 'bleu-bromophenol.svg.png', 'rouge-methyle.svg.png']
-    simulRequest=pyqtSignal()
-    clearCourbes=pyqtSignal()
-    
+    indicators = ['rien.svg.png', 'bbt.svg.png', 'phenolphtaleine.svg.png',
+                  'helianthine.svg.png', 'bleu-bromophenol.svg.png',
+                  'rouge-methyle.svg.png']
+    simulRequest = pyqtSignal()
+    clearCourbes = pyqtSignal()
+
     def __init__(self, parent, argv, locale="en_US"):
         """
         Le constructeur
         @param parent une fenêtre parente
         @argv une liste d'arguments
-        """       
-        
-        ######QT
+        """
+
+        # #####QT
         QMainWindow.__init__(self)
-        self.windowTitle="pyAcidoBasic"
+        self.windowTitle = "pyAcidoBasic"
         QWidget.__init__(self, parent)
         
+        # this becomes effective in Debian, when all icons/ are replaced
+        # by icons in paths defined in the file Ui_main.py
+        QDir.addSearchPath('icons', '/usr/share/pyacidobasic/pyacidobasic/icons')
         from .Ui_main import Ui_MainWindow
         self.ui = Ui_MainWindow()
-        
-        self.filename=""
 
-        self.courbesActives=[] # la liste des courbes qu'on peut montrer/cacher
+        self.filename = ""
+
+        self.courbesActives = []  # la liste des courbes qu'on peut montrer/cacher
         self.ui.setupUi(self)
         # état initial des boutons radio concentrations/quantités
-        self.showConcentrations=True
+        self.showConcentrations = True
         # substitution des traceurs de courbes
-        ####### traceur orienté pH
+        # ###### traceur orienté pH
         self.ui.verticalLayout_labCourbes.removeWidget(self.ui.plotpH)
         self.ui.plotpH.close()
-        self.ui.plotpH=phPlot(
+        self.ui.plotpH = phPlot(
             self.ui.tabWidget,
             axisLabels=("pH", self.labelQte()),
-            colors=("b","b"),
-        )
-        self.ui.verticalLayout_labCourbes.insertWidget (1,self.ui.plotpH)
-        ####### traceur orienté concentrations
+            colors=("b", "b"),)
+        self.ui.verticalLayout_labCourbes.insertWidget(1, self.ui.plotpH)
+        # ###### traceur orienté concentrations
         self.ui.horizontalLayout_concentrationCourbes.removeWidget(self.ui.plotQM)
         self.ui.plotQM.close()
-        self.ui.plotQM=phPlot(
+        self.ui.plotQM = phPlot(
             self.ui.tabWidget,
-            axisLabels=(self.labelQte(),"pH"),
-            colors=("b","b"),
-        )
-        self.ui.horizontalLayout_concentrationCourbes.insertWidget (1,self.ui.plotQM)
+            axisLabels=(self.labelQte(), "pH"),
+            colors=("b", "b"),)
+        self.ui.horizontalLayout_concentrationCourbes.insertWidget(1, self.ui.plotQM)
         ######
-        self.plots=(self.ui.plotpH,self.ui.plotQM)
+        self.plots = (self.ui.plotpH, self.ui.plotQM)
         # volume max versé de la burette
-        self.maxBurette=20
-        
-        ###### INDICATEUR COLORE
+        self.maxBurette = 20
+
+        # ##### INDICATEUR COLORE
         self.clear()
         self.colors()
-        ###### INDICATEUR COLORE
+        # ##### INDICATEUR COLORE
 
         self.configurePlot()
-        dbFile=os.path.join("/usr/share/pyacidobasic/lang","db-{loc}.html".format(loc=locale))
+        dbFile = os.path.join("/usr/share/pyacidobasic/lang",
+                              "db-{loc}.html".format(loc=locale))
         if os.path.exists(dbFile):
-            self.abListe=abHTMLparser(dbFile).parseTableToList()
+            self.abListe = abHTMLparser(dbFile).parseTableToList()
         else:
-            locale=locale[:-3]
-            dbFile=os.path.join("/usr/share/pyacidobasic/lang","db-{loc}.html".format(loc=locale))
+            locale = locale[:-3]
+            dbFile = os.path.join("/usr/share/pyacidobasic/lang",
+                                  "db-{loc}.html".format(loc=locale))
             if os.path.exists(dbFile):
-                self.abListe=abHTMLparser(dbFile).parseTableToList()
+                self.abListe = abHTMLparser(dbFile).parseTableToList()
             else:
-                self.abListe=abHTMLparser("/usr/share/pyacidobasic/lang/db-en_US.html").parseTableToList()
-        self.filterChanged("") # met en place la liste des acides et des bases
+                self.abListe = abHTMLparser("/usr/share/pyacidobasic\
+                                             /lang/db-en_US.html").parseTableToList()
+        self.filterChanged("")  # met en place la liste des acides et des bases
         self.ui_connections()
         self.simulRequest.connect(self.simule)
         self.clearCourbes.connect(self.clear)
-        if len(argv)>1:
+        if len(argv) > 1:
             if os.path.exists(argv[1]):
                 self.load(argv[1])
-        
 
     def labelQte(self):
         """
@@ -142,7 +154,7 @@ class acidoBasicMainWindow(QMainWindow):
             return "concentration (mol·L<sup>-1</sup>)"
         else:
             return "quantité de matière (mol)"
-        
+
     def titreQte(self):
         """
         @return le titre de concentration ou de quantité de matière
@@ -152,28 +164,32 @@ class acidoBasicMainWindow(QMainWindow):
             return "Évolution des concentrations"
         else:
             return "Évolution des quantités de matière"
-        
+
     def simule(self):
         self.clearCourbesControles()
         if not self.simulationPossible():
             self.configurePlot()
             self.replot()
             return
-        
-        self.vData=[]; self.pHData=[]; self.derivData=[]
-        self.maxpH=0.0
-        for i in range (1401):
-            pH=0.01*i # pH varie de 0 à 14
+
+        self.vData = []
+        self.pHData = []
+        self.derivData = []
+        self.maxpH = 0.0
+        for i in range(1401):
+            pH = 0.01*i  # pH varie de 0 à 14
             try:
-                v=-self.ui.listWidgetBecher.charge(pH)/self.ui.listWidgetBurette.charge(pH,1)
-                if v>0:
+                v = -self.ui.listWidgetBecher.charge(pH) \
+                    / self.ui.listWidgetBurette.charge(pH, 1)
+                if v > 0:
                     self.vData.append(v)
                     self.pHData.append(pH)
-                    if len(self.pHData)>1:
+                    if len(self.pHData) > 1:
                         self.derivData.append(0.01/(self.vData[-1]-self.vData[-2]))
                     else:
                         self.derivData.append(0.0)
-                    if pH > self.maxpH: self.maxpH=pH
+                    if pH > self.maxpH:
+                        self.maxpH = pH
             except ZeroDivisionError:
                 pass
         self.courbesSysteme()
@@ -182,13 +198,13 @@ class acidoBasicMainWindow(QMainWindow):
         # essaie d'ajuster le volume de burette pour voir la partie intéressante
         try:
             # trouve l'abscisse pour avoir ph < maxpH - 0.5
-            i=0
+            i = 0
             while self.pHData[i] < self.maxpH - 0.5:
-                i+=1
-                v= self.vData[i]
+                i += 1
+                v = self.vData[i]
             # ajuste le volume versé depuis la burette à 5mL près
-            self.maxBurette=5*(1+int(v)/5)
-        except:
+            self.maxBurette = 5*(1+int(v)/5)
+        except ValueError:
             pass
         self.configurePlot()
         self.replot()
@@ -225,20 +241,23 @@ class acidoBasicMainWindow(QMainWindow):
         """
         Met à jour le titre de la fenêtre
         """
-        self.setWindowTitle("Pyacidobasic : %s" % os.path.basename(self.filename))
-        
-            
+        self.setWindowTitle(f"Pyacidobasic : {os.path.basename(self.filename)}")
+
     def saveAs(self):
         """
         Enregistre les données du graphique sous un nouveau fichier
         """
-        fname=QFileDialog.getSaveFileName (self, QApplication.translate("pyacidobasic","File to save")
-, filter=QApplication.translate("pyacidobasic","Acidobasic files [*.acb] (*.acb);; All files (*.* *)"))
-        fname=fname[0]
+        fname = QFileDialog.getSaveFileName(
+            self,
+            QApplication.translate("pyacidobasic", "File to save"),
+            filter=QApplication.translate("pyacidobasic",
+                                          "Acidobasic files [*.acb] (*.acb);;\
+                                           All files (*.* *)"))
+        fname = fname[0]
         if fname:
-            if not re.match(".*\.\S*$",fname):
-                fname+=".acb" #on ajoute un suffixe par défaut
-            self.filename=fname
+            if not re.match(r".*\.\S*$", fname):
+                fname += ".acb"  # on ajoute un suffixe par défaut
+            self.filename = fname
             self.updateWindowTitle()
             self.save()
 
@@ -250,8 +269,7 @@ class acidoBasicMainWindow(QMainWindow):
             obj = {
                 "version": versionString,
                 "burette": self.ui.listWidgetBurette,
-                "becher": self.ui.listWidgetBecher,
-            }
+                "becher": self.ui.listWidgetBecher}
             with open(self.filename, "w") as outfile:
                 outfile.write(jsonpickle.encode(obj, indent=2))
         else:
@@ -268,12 +286,17 @@ class acidoBasicMainWindow(QMainWindow):
         Récupère les données depuis un fichier
         """
         if not fname:
-            fname=QFileDialog.getOpenFileName (self, QApplication.translate("pyacidobasic", "File to save"), filter=QApplication.translate("pyacidobasic", "Acidobasic files [*.acb] (*.acb);; All files (*.* *)"), directory=dir)[0]
+            fname = QFileDialog.getOpenFileName(
+                self,
+                QApplication.translate("pyacidobasic", "File to save"),
+                filter=QApplication.translate("pyacidobasic",
+                                              "Acidobasic files [*.acb] (*.acb);;\
+                                               All files (*.* *)"), directory=dir)[0]
         if fname:
-            self.filename=fname
-            p=pickle.Unpickler(open(self.filename,"rb"))
+            self.filename = fname
+            p = pickle.Unpickler(open(self.filename, "rb"))
             try:
-                versionString_=p.load().decode("utf-8")
+                # versionString = p.load().decode("utf-8")
                 self.ui.listWidgetBurette.load(p.load())
                 self.ui.listWidgetBecher.load(p.load())
                 self.updateWindowTitle()
@@ -285,33 +308,40 @@ class acidoBasicMainWindow(QMainWindow):
                 self.updateWindowTitle()
                 self.replot()
             except Exception as err:
-                QMessageBox.warning (self, QApplication.translate("pyacidobasic", "Version error"), QApplication.translate("pyacidobasic", "This file is not a valid Pyacidobasic file, version %s. Error: %s ; %s") % (version,err, type(err)))
+                QMessageBox.warning(
+                    self,
+                    QApplication.translate("pyacidobasic", "Version error"),
+                    QApplication.translate(
+                        "pyacidobasic",
+                        f"This file is not a valid Pyacidobasic file, \
+                        version {version}. Error: {err} ; {type(err)}"))
 
     def apropos(self):
         """
         Donne un message d'information au sujet de la licence de pyacidobasic
         """
         global locale
-        if locale[:2]=="fr":
-            l="fr"
+        if locale[:2] == "fr":
+            ln = "fr"
         else:
-            l="en"
-        msg=licence[l] %version
-        QMessageBox.information(self, QApplication.translate("pyacidobasic", "About"), msg)
-            
+            ln = "en"
+        msg = licence[ln] % version
+        QMessageBox.information(self, QApplication.translate("pyacidobasic",
+                                                             "About"), msg)
+
     def QMchanged(self, concentration):
         """
         Fonction de rappel pour le changement d'état du bouton radio de
         concentrations.
         @param concentration booléen vrai si on doit afficher des concentrations
         """
-        self.showConcentrations=concentration
+        self.showConcentrations = concentration
         self.clear()
         self.courbesSysteme()
         self.ajouteSolutes()
         self.configurePlot()
         return
-        
+
     def razFiltre(self):
         """
         Remet à zéro le filtre pour choisir les réactifs
@@ -320,21 +350,21 @@ class acidoBasicMainWindow(QMainWindow):
 
     def plusV(self):
         if self.maxBurette < 5:
-            self.maxBurette+=1
+            self.maxBurette += 1
         else:
-            self.maxBurette+=5
+            self.maxBurette += 5
         self.replot()
 
     def moinsV(self):
         if self.maxBurette >= 10:
-            self.maxBurette-=5
-        elif self.maxBurette >=2:
-            self.maxBurette-=1
+            self.maxBurette -= 5
+        elif self.maxBurette >= 2:
+            self.maxBurette -= 1
         self.replot()
 
     def replot(self):
         for pw in self.plots:
-            pw.setXRange(0,self.maxBurette)
+            pw.setXRange(0, self.maxBurette)
         self.colors()
         return
 
@@ -345,56 +375,56 @@ class acidoBasicMainWindow(QMainWindow):
     def videBecher(self):
         self.ui.listWidgetBecher.vide()
         self.simule()
-       
+
     def filterChanged(self, newtext):
         """
         Fonction de rappel quand le texte du filtre change
         @param newtext le texte actuel du filtre
         """
-        reactifs_setupUi(self.ui,self.abListe, newtext)
-       
+        reactifs_setupUi(self.ui, self.abListe, newtext)
+
     def maxConcentration(self):
         """
         @return la concentration du plus concentré des réactifs
         """
-        burette=self.ui.listWidgetBurette
-        becher=self.ui.listWidgetBecher
+        burette = self.ui.listWidgetBurette
+        becher = self.ui.listWidgetBecher
 
         maxi = 0
-        if len (burette.contenu)>0:
-            maxi=burette.contenu[0].c
+        if len(burette.contenu) > 0:
+            maxi = burette.contenu[0].c
         for b in becher.contenu:
             if b.c > maxi :
-                maxi=b.c
+                maxi = b.c
         if maxi <= 0:
             return None
         else:
             return maxi
-        
+
     def maxQuantite(self):
         """
         @return la quantité du plus concentré des réactifs à considérer
         """
-        burette=self.ui.listWidgetBurette
-        becher=self.ui.listWidgetBecher
+        burette = self.ui.listWidgetBurette
+        becher = self.ui.listWidgetBecher
 
         maxi = 0
-        if len (burette.contenu)>0:
-            maxi=burette.contenu[0].c*20e-3 # pour 20 mL max de burette !
+        if len(burette.contenu) > 0:
+            maxi = burette.contenu[0].c*20e-3  # pour 20 mL max de burette !
         for b in becher.contenu:
             if b.c > maxi :
-                maxi=b.c*1e-3*b.v
+                maxi = b.c*1e-3*b.v
         if maxi <= 0:
             return None
         else:
             return maxi
-        
+
     def vTotal(self):
         """
         @return un vecteur de valeurs de volume total de la solution
         """
-        becher=self.ui.listWidgetBecher
-        totalBecher=0
+        becher = self.ui.listWidgetBecher
+        totalBecher = 0
         for c in becher.contenu:
             totalBecher += c.v
         return totalBecher*np.ones(len(self.pHData))+self.vData
@@ -410,31 +440,30 @@ class acidoBasicMainWindow(QMainWindow):
         @param width l'épaisseur, 1 par défaut
         @param yData la liste de données pour Y (c'est self.vData pour X)
         @param pw un PlotWidget, celui des pH par défaut
-        @param modifiable si on doit mettre une case active dans le tableau (vrai par défaut)
-        @param checked si la case est pré-cochée (faux par défaut)
+        @param modifiable si on doit mettre une case active dans le tableau (vrai par
+        @param  défaut) checked si la case est pré-cochée (faux par défaut)
         """
 
-        if self.row > 3 and color=="black":
+        if self.row > 3 and color == "black":
             # couleurs variables
-            color=self.varColor()
+            color = self.varColor()
         else:
-            color=QColor(color)
-            
-        if yAxis=="left":
-            index=0
-        else:
-            index=1
+            color = QColor(color)
 
-        newCourbe=pw.plot(
+        if yAxis == "left":
+            index = 0
+        else:
+            index = 1
+
+        newCourbe = pw.plot(
             x=self.vData, y=yData,
-                  pen=pg.mkPen(color, width=width),
-                  name=titre,
-                  index=index
-        )
+            pen=pg.mkPen(color, width=width),
+            name=titre,
+            index=index)
 
         # on crée un curveControl quand c'est sur l'axe gauche
-        if yAxis=="left":
-            newCourbe.cc=CurveControl(
+        if yAxis == "left":
+            newCourbe.cc = CurveControl(
                 None,
                 mw=self,
                 html=titre,
@@ -448,117 +477,115 @@ class acidoBasicMainWindow(QMainWindow):
             else:
                 newCourbe.hide()
             self.ui.curveControlLayout.addWidget(newCourbe.cc)
-        self.row+=1
+        self.row += 1
         return
 
     def varColor(self):
         """
         @return une nouvelle couleur pour chaque self.row
         """
-        r=np.sin(self.row*np.pi/2)
-        v=np.sin(self.row*np.pi/3)
-        b=np.sin(self.row*np.pi/5)
-        r=round((1+r)/2*255)
-        v=round((1+v)/2*255)
-        b=round((1+b)/2*255)
-        return QColor(r,v,b)
+        r = np.sin(self.row*np.pi/2)
+        v = np.sin(self.row*np.pi/3)
+        b = np.sin(self.row*np.pi/5)
+        r = round((1+r)/2*255)
+        v = round((1+v)/2*255)
+        b = round((1+b)/2*255)
+        return QColor(r, v, b)
 
     def ajouteSolutes(self):
         """
         Ajoute toutes les espèces présentes, dans le menu du graphique
         """
-        burette=self.ui.listWidgetBurette
-        becher=self.ui.listWidgetBecher
+        burette = self.ui.listWidgetBurette
+        becher = self.ui.listWidgetBecher
 
-        buretteCalculee=False
+        buretteCalculee = False
         for c in burette.contenu + becher.contenu:
             for i in range(len(c.formes)):
-                if buretteCalculee: # la calcul n'est plus pour la burette
-                    yData=c.concentrationParPH(
-                        i,self.pHData,self.vTotal(),
+                if buretteCalculee:  # la calcul n'est plus pour la burette
+                    yData = c.concentrationParPH(
+                        i, self.pHData, self.vTotal(),
                         vBurette=None)
                 else:
-                    yData=c.concentrationParPH(
-                        i,self.pHData,self.vTotal(),
+                    yData = c.concentrationParPH(
+                        i, self.pHData, self.vTotal(),
                         vBurette=self.vData)
-                    buretteCalculee=True
+                    buretteCalculee = True
                 if self.showConcentrations :
-                    titre="[%s]" %c.formes[i]
+                    titre = f"[{c.formes[i]}]"
                 else:
                     # on change les données de concentration en qté de matière
-                    yData*=1e-3*self.vTotal()
-                    titre="n<sub>%s</sub>" %c.formes[i]
+                    yData *= 1e-3*self.vTotal()
+                    titre = f"n<sub>{c.formes[i]}</sub>"
                 self.nouvelleCourbe(titre=titre,
                                     yAxis='left',
                                     yData=yData,
                                     pw=self.ui.plotQM,
                                     width=2,
                                     modifiable=True,
-                                    checked=True,
-                                    )
+                                    checked=True,)
         return
-    
+
     def clearCourbesControles(self):
         """
         Supprime les courbes et leurs contôles
         """
         self.clear()
-        s=self.ui.curveControlLayout
-        #nettoyage des anciens contrôles
-        child=s.takeAt(0)
+        s = self.ui.curveControlLayout
+        # nettoyage des anciens contrôles
+        child = s.takeAt(0)
         while child:
             child.widget().close()
             del child
-            child=s.takeAt(0)
+            child = s.takeAt(0)
 
     def clear(self):
         """
         Supprimes courbes et legendes
         """
-        #nettoyage des anciennes courbes et remise à zéro des légendes
+        # nettoyage des anciennes courbes et remise à zéro des légendes
         for p in self.ui.plotpH, self.ui.plotQM :
             p.clearAll()
-        # rétablit l'image de fond pour l'indicateur coloré 
-        self.indic=pg.ImageItem()
+        # rétablit l'image de fond pour l'indicateur coloré
+        self.indic = pg.ImageItem()
         self.ui.plotpH.addItem(self.indic)
         return
 
     def courbesSysteme(self):
         """
-        Crée les courbes "système" : pH, dpH/dV, [H<sub>3</sub>O<sup>+</sup>], [HO<sup>-</sup>]
+        Crée les courbes "système" : pH, dpH/dV, [H<sub>3</sub>O<sup>+</sup>],
+        [HO<sup>-</sup>]
         """
         self.clearCourbesControles()
-        self.row=0
-        ################### le pH ######################
+        self.row = 0
+        # ################## le pH ######################
         self.nouvelleCourbe(titre="pH",
                             color="red",
                             yAxis='left',
                             yData=self.pHData,
                             pw=self.ui.plotpH,
                             modifiable=False,
-                            checked=True,
-        )
-        ###### le pH dans la vue des concentrations ###############
+                            checked=True,)
+        # ##### le pH dans la vue des concentrations ###############
         # il faut mettre le pH à la bonne échelle
         self.nouvelleCourbe(titre="pH",
-                            color=QColor(255,0,0,50),
+                            color=QColor(255, 0, 0, 50),
                             yAxis='right',
                             yData=np.array(self.pHData),
                             pw=self.ui.plotQM,
                             modifiable=False,
                             checked=True,
-                            width=1,
-        )
-        ###### dpH/dV dans la vue du pH ###############
+                            width=1,)
+        # ##### dpH/dV dans la vue du pH ###############
         # il faut mettre le dpH/dV  à la bonne échelle
         # car on triche, on le met dans l'axe gauche
-        d=np.array(self.derivData)
-        reduction=14/max(d)
-        if d.min()<0:
-            d= 14.0+d # décalage en cas de dosage par un acide !
-            titre="14+dpH/dV"
+        d = np.array(self.derivData)
+        reduction = 14/max(d)
+        if d.min() < 0:
+            d += 14.0  # décalage en cas de dosage par un acide !
+            titre = "14+dpH/dV"
         else:
-            titre="dpH/dV"
+            titre = "dpH/dV"
         self.nouvelleCourbe(titre=titre,
                             color="blue",
                             yAxis='left',
@@ -566,42 +593,39 @@ class acidoBasicMainWindow(QMainWindow):
                             pw=self.ui.plotpH,
                             width=1,
                             modifiable=False,
-                            checked=True,
-        )
-        ###### dpH/dV dans la vue des concentrations ###############
+                            checked=True,)
+        # ##### dpH/dV dans la vue des concentrations ###############
         # il faut mettre le dpH/dV  à la bonne échelle
-        reduction=14/max(d)
+        reduction = 14/max(d)
         self.nouvelleCourbe(titre=titre,
-                            color=QColor(0,0,255,50),
+                            color=QColor(0, 0, 255, 50),
                             yAxis='right',
                             yData=reduction*d,
                             pw=self.ui.plotQM,
                             width=1,
                             modifiable=False,
-                            checked=True,
-        )
-        ###### oxonium dans la vue du pH ###############
-        H3OData=np.exp(- 2.302585093*np.array(self.pHData))
+                            checked=True,)
+        # ##### oxonium dans la vue du pH ###############
+        H3OData = np.exp(- 2.302585093*np.array(self.pHData))
         if self.showConcentrations :
-            titre="[H<sub>3</sub>O<sup>+</sup>]"
+            titre = "[H<sub>3</sub>O<sup>+</sup>]"
         else:
-            H3OData*=1e-3*self.vTotal()
-            titre="n<sub>H<sub>3</sub>O<sup>+</sup></sub>"
+            H3OData *= 1e-3*self.vTotal()
+            titre = "n<sub>H<sub>3</sub>O<sup>+</sup></sub>"
         self.nouvelleCourbe(titre=titre,
                             color="green",
                             yData=H3OData,
                             pw=self.ui.plotpH,
                             width=1,
-                            yAxis="right",
-        )
-        ###### oxonium dans la vue des concentrations ###############
+                            yAxis="right",)
+        # ##### oxonium dans la vue des concentrations ###############
         # il faut mettre les oxonimums  à la bonne échelle
-        H3OData=np.exp(- 2.302585093*np.array(self.pHData))
+        H3OData = np.exp(- 2.302585093*np.array(self.pHData))
         if self.showConcentrations :
-            titre="[H<sub>3</sub>O<sup>+</sup>]"
+            titre = "[H<sub>3</sub>O<sup>+</sup>]"
         else:
-            H3OData*=1e-3*self.vTotal()
-            titre="n<sub>H<sub>3</sub>O<sup>+</sup></sub>"
+            H3OData *= 1e-3*self.vTotal()
+            titre = "n<sub>H<sub>3</sub>O<sup>+</sup></sub>"
         self.nouvelleCourbe(titre=titre,
                             color="green",
                             yData=H3OData,
@@ -609,29 +633,27 @@ class acidoBasicMainWindow(QMainWindow):
                             pw=self.ui.plotQM,
                             width=2,
                             modifiable=True,
-                            checked=True,
-        )
-        ###### hydroxydes dans la vue du pH ###############
-        HOData=1e-14/np.exp(- 2.302585093*np.array(self.pHData))
+                            checked=True,)
+        # ##### hydroxydes dans la vue du pH ###############
+        HOData = 1e-14/np.exp(- 2.302585093*np.array(self.pHData))
         if self.showConcentrations :
-            titre="[HO<sup>-</sup>]"
+            titre = "[HO<sup>-</sup>]"
         else:
-            HOData*=1e-3*self.vTotal()
-            titre="n<sub>HO<sup>-</sup></sub>"
+            HOData *= 1e-3*self.vTotal()
+            titre = "n<sub>HO<sup>-</sup></sub>"
         self.nouvelleCourbe(titre=titre,
                             color="magenta",
                             yData=HOData,
                             pw=self.ui.plotpH,
                             width=1,
-                            yAxis="right",
-        )
-        ###### hydroxyde dans la vue des concentrations ###############
-        HOData=1e-14/np.exp(- 2.302585093*np.array(self.pHData))
+                            yAxis="right",)
+        # ##### hydroxyde dans la vue des concentrations ###############
+        HOData = 1e-14/np.exp(- 2.302585093*np.array(self.pHData))
         if self.showConcentrations :
-            titre="[HO<sup>-</sup>]"
+            titre = "[HO<sup>-</sup>]"
         else:
-            HOData*=1e-3*self.vTotal()
-            titre="n<sub>HO<sup>-</sup></sub>"
+            HOData *= 1e-3*self.vTotal()
+            titre = "n<sub>HO<sup>-</sup></sub>"
         self.nouvelleCourbe(titre=titre,
                             color="magenta",
                             yData=HOData,
@@ -639,24 +661,22 @@ class acidoBasicMainWindow(QMainWindow):
                             pw=self.ui.plotQM,
                             width=2,
                             modifiable=True,
-                            checked=True,
-        )
+                            checked=True,)
         return
-        
 
     def simulationPossible(self):
         """
         @return un boolean vrai si une simulation est possible
         """
-        return len(self.ui.listWidgetBecher.contenu)>0 and len(self.ui.listWidgetBurette.contenu)>0
+        return len(self.ui.listWidgetBecher.contenu) > 0 \
+            and len(self.ui.listWidgetBurette.contenu) > 0
 
     def event(self, ev):
-        if ev.type()==QEvent.User:
+        if ev.type() == QEvent.Type.User:
             self.simule()
             return True
         else:
-            return QMainWindow.event(self,ev)
-
+            return QMainWindow.event(self, ev)
 
     def concentrationViewRangeY(self):
         """
@@ -664,22 +684,22 @@ class acidoBasicMainWindow(QMainWindow):
         l'axe vertical
         """
         if self.showConcentrations:
-            maxi=self.maxConcentration()
+            maxi = self.maxConcentration()
         else:
-            maxi=self.maxQuantite()
+            maxi = self.maxQuantite()
         if maxi:
-            return (0,1.25*maxi)
+            return (0, 1.25*maxi)
         else:
-            return (0,0.1)
+            return (0, 0.1)
 
     def configurePlot(self):
         """
         Choisit les axes et les gradue
         """
         if self.showConcentrations:
-            yRightMax=self.maxConcentration()
+            yRightMax = self.maxConcentration()
         else:
-            yRightMax=self.maxQuantite()
+            yRightMax = self.maxQuantite()
         self.ui.plotpH.setGrid(
             titre="dosage pHmétrique",
             yRightTitre=self.labelQte(),
@@ -687,9 +707,9 @@ class acidoBasicMainWindow(QMainWindow):
             yLeftMax=14,
         )
         if self.showConcentrations:
-            yLeftMax=self.maxConcentration()
+            yLeftMax = self.maxConcentration()
         else:
-            yLeftMax=self.maxQuantite()
+            yLeftMax = self.maxQuantite()
         self.ui.plotQM.setGrid(
             titre=self.titreQte(),
             yLeftTitre=self.labelQte(),
@@ -702,37 +722,37 @@ class acidoBasicMainWindow(QMainWindow):
         """
         met en place la couleur de fond de l'indicateur coloré choisi
         """
-        self.pngFile=os.path.join('/usr/share/pyacidobasic/pyacidobasic/icons', self.indicators[self.ui.comboBox_indicator1.currentIndex()])
-        img=PIL.Image.open(self.pngFile)
-        imgArray=np.frombuffer(img.tobytes(), dtype=np.uint8)
-        imgArray=imgArray.reshape((img.size[1], img.size[0], 4))
+        self.pngFile = os.path.join(
+            '/usr/share/pyacidobasic/pyacidobasic/icons',
+            self.indicators[self.ui.comboBox_indicator1.currentIndex()])
+        img = PIL.Image.open(self.pngFile)
+        imgArray = np.frombuffer(img.tobytes(), dtype=np.uint8)
+        imgArray = imgArray.reshape((img.size[1], img.size[0], 4))
         self.indic.setImage(image=imgArray)
-        self.indic.setRect(QRectF(0,0,self.ui.plotpH.plotItem.vb.width(),14))
-
-
-locale="" # cette variable est globale, elle est initialisée au démarrage
-
+        self.indic.setRect(QRectF(0, 0, self.ui.plotpH.plotItem.vb.width(), 14))
 
+locale = ""  # cette variable est globale, elle est initialisée au démarrage
 
 def run():
     global locale
     app = QApplication(sys.argv)
 
-    ###translation##
+    # ##translation##
     locale = QLocale.system().name()
     qtTranslator = QTranslator()
 
     if qtTranslator.load("qt_" + locale):
         app.installTranslator(qtTranslator)
-        
+
     appTranslator = QTranslator()
-    if appTranslator.load(os.path.join(os.path.dirname(__file__),"../lang/pyacidobasic_" + locale)):
+    if appTranslator.load(os.path.join(os.path.dirname(__file__),
+                          "../lang/pyacidobasic_" + locale)):
         # les traductions en mode développement sont prioritaires
         app.installTranslator(appTranslator)
     elif appTranslator.load("/usr/share/pyacidobasic/lang/pyacidobasic_" + locale):
         # par rapport aux traductions déjà installées par le paquet debian
         app.installTranslator(appTranslator)
-        
-    w = acidoBasicMainWindow(None,sys.argv, locale=locale)
+
+    w = acidoBasicMainWindow(None, sys.argv, locale=locale)
     w.show()
-    sys.exit(app.exec_())
+    sys.exit(app.exec())
